package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbCareerClass;

import java.util.List;
import java.util.Map;

/**
 * 职业分类Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-10
 */
public interface TbCareerClassMapper
{
    /**
     * 查询职业分类
     *
     * @param careerId 职业分类主键
     * @return 职业分类
     */
    public TbCareerClass selectTbCareerClassByCareerId(Long careerId);

    /**
     * 查询职业分类列表
     *
     * @param tbCareerClass 职业分类
     * @return 职业分类集合
     */
    public List<TbCareerClass> selectTbCareerClassList(TbCareerClass tbCareerClass);

    /**
     * 新增职业分类
     *
     * @param tbCareerClass 职业分类
     * @return 结果
     */
    public int insertTbCareerClass(TbCareerClass tbCareerClass);

    /**
     * 修改职业分类
     *
     * @param tbCareerClass 职业分类
     * @return 结果
     */
    public int updateTbCareerClass(TbCareerClass tbCareerClass);

    /**
     * 删除职业分类
     *
     * @param careerId 职业分类主键
     * @return 结果
     */
    public int deleteTbCareerClassByCareerId(Long careerId);

    /**
     * 批量删除职业分类
     *
     * @param careerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbCareerClassByCareerIds(Long[] careerIds);

    /**
     * 职业分类列表
     *
     * @param params 参数
     * @return 职业分类集合列表
     */
    public List<Map<String, Object>> selectTbCareerClassMapList(Map<String, Object> params);
}
